pub enum HealthCheck {
FilterTooMuch,
TooSlow,
TestCasesTooLarge,
LargeInitialTestCase,
}Expand description
Health checks that can be suppressed during test execution.
Health checks detect common issues with test configuration that would otherwise cause tests to run inefficiently or not at all.
Variants
FilterTooMuch
Too many test cases are being filtered out via assume().
TooSlow
Test execution is too slow.
TestCasesTooLarge
Generated test cases are too large.
LargeInitialTestCase
The smallest natural input is very large.
Implementations
Sourceimpl HealthCheck
impl HealthCheck
Sourcepub const fn all() -> [HealthCheck; 4]
pub const fn all() -> [HealthCheck; 4]
Returns all health check variants.
Useful for suppressing all health checks at once:
use hegel::HealthCheck;
#[hegel::test(suppress_health_check = HealthCheck::all())]
fn my_test(tc: hegel::TestCase) {
// ...
}Trait Implementations
Sourceimpl Clone for HealthCheck
impl Clone for HealthCheck
Sourcefn clone(&self) -> HealthCheck
fn clone(&self) -> HealthCheck
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HealthCheck
impl Debug for HealthCheck
Sourceimpl Hash for HealthCheck
impl Hash for HealthCheck
Sourceimpl PartialEq for HealthCheck
impl PartialEq for HealthCheck
impl Copy for HealthCheck
impl Eq for HealthCheck
impl StructuralPartialEq for HealthCheck