pub struct CharactersGenerator { /* private fields */ }Expand description
Generator for single Unicode characters (char). Created by characters().
Implementations
Sourceimpl CharactersGenerator
impl CharactersGenerator
Sourcepub fn codec(self, codec: &str) -> Self
pub fn codec(self, codec: &str) -> Self
Restrict to characters encodable in this codec (e.g. "ascii", "utf-8", "latin-1").
Sourcepub fn min_codepoint(self, min_codepoint: u32) -> Self
pub fn min_codepoint(self, min_codepoint: u32) -> Self
Set the minimum Unicode codepoint.
Sourcepub fn max_codepoint(self, max_codepoint: u32) -> Self
pub fn max_codepoint(self, max_codepoint: u32) -> Self
Set the maximum Unicode codepoint.
Sourcepub fn categories(self, categories: &[&str]) -> Self
pub fn categories(self, categories: &[&str]) -> Self
Include only characters from these Unicode general categories (e.g. ["L", "Nd"]).
Mutually exclusive with exclude_categories.
Sourcepub fn exclude_categories(self, exclude_categories: &[&str]) -> Self
pub fn exclude_categories(self, exclude_categories: &[&str]) -> Self
Exclude characters from these Unicode general categories.
Mutually exclusive with categories.
Sourcepub fn include_characters(self, include_characters: &str) -> Self
pub fn include_characters(self, include_characters: &str) -> Self
Always include these specific characters, even if excluded by other filters.
Sourcepub fn exclude_characters(self, exclude_characters: &str) -> Self
pub fn exclude_characters(self, exclude_characters: &str) -> Self
Always exclude these specific characters.