FloatGenerator

Struct FloatGenerator 

pub struct FloatGenerator<T> { /* private fields */ }
Generator for floating-point values. Created by floats().

By default, may produce NaN and infinity when no bounds are set. Setting bounds automatically disables these unless re-enabled.

Implementations

Source

impl<T> FloatGenerator<T>

pub fn min_value(self, min_value: T) -> Self

Set the minimum value (inclusive by default).

pub fn max_value(self, max_value: T) -> Self

Set the maximum value (inclusive by default).

pub fn exclude_min(self, exclude_min: bool) -> Self

Set whether to exclude the minimum value from the range.

pub fn exclude_max(self, exclude_max: bool) -> Self

Set whether to exclude the maximum value from the range.

pub fn allow_nan(self, allow: bool) -> Self

Whether NaN values are allowed. Cannot be used with bounds.

pub fn allow_infinity(self, allow: bool) -> Self

Whether infinite values are allowed. Cannot be used with both bounds set.