Variables

Struct Variables 

pub struct Variables<T> { /* private fields */ }
A pool of previously generated values.

Implementations

Source

impl<T> Variables<T>

pub fn is_empty(&self) -> bool

Returns true if no variables are in the pool.

pub fn len(&self) -> usize

Number of variables currently in the pool.

pub fn add(&mut self, v: T)

Add a value to the pool.

Examples found in repository?
examples/ledger.rs (line 53)
50    fn create_account(&mut self, tc: TestCase) {
51        let account = tc.draw(gs::text().min_size(1));
52        tc.note(&format!("create account '{}'", account.clone()));
53        self.accounts.add(account);
54    }
pub fn draw(&self) -> &T

Draw a reference to a value from the pool (without removing it).

Calls assume(false) if the pool is empty.

Examples found in repository?
examples/ledger.rs (line 58)
57    fn credit(&mut self, tc: TestCase) {
58        let account = self.accounts.draw().clone();
59        let amount = tc.draw(gs::integers::<i64>().min_value(0).max_value(LIMIT));
60        tc.note(&format!("credit '{}' with {}", account.clone(), amount));
61        self.ledger.credit(account, amount);
62    }
63
64    #[rule]
65    fn transfer(&mut self, tc: TestCase) {
66        let from = self.accounts.draw().clone();
67        let to = self.accounts.draw().clone();
68        let amount = tc.draw(gs::integers::<i64>().min_value(0).max_value(LIMIT));
69        tc.note(&format!(
70            "transfer '{}' from {} to {}",
71            amount,
72            from.clone(),
73            to.clone()
74        ));
75        self.ledger.transfer(from, to, amount);
76    }
pub fn consume(&mut self) -> T

Remove and return a value from the pool.

Calls assume(false) if the pool is empty.