HealthCheck

Enum HealthCheck 

pub enum HealthCheck {
    FilterTooMuch,
    TooSlow,
    TestCasesTooLarge,
    LargeInitialTestCase,
}
Health checks that can be suppressed during test execution.

Health checks detect common issues with test configuration that would otherwise cause tests to run inefficiently or not at all.

Variants



FilterTooMuch

Too many test cases are being filtered out via assume().



TooSlow

Test execution is too slow.



TestCasesTooLarge

Generated test cases are too large.



LargeInitialTestCase

The smallest natural input is very large.

Implementations

Source

impl HealthCheck

pub const fn all() -> [HealthCheck; 4]

Returns all health check variants.

Useful for suppressing all health checks at once:

use hegel::HealthCheck;

#[hegel::test(suppress_health_check = HealthCheck::all())]
fn my_test(tc: hegel::TestCase) {
    // ...
}