pub struct FloatGenerator<T> { /* private fields */ }Expand description
Generator for floating-point values. Created by floats().
By default, may produce NaN and infinity when no bounds are set. Setting bounds automatically disables these unless re-enabled.
Implementations
Sourceimpl<T> FloatGenerator<T>
impl<T> FloatGenerator<T>
Sourcepub fn exclude_min(self, exclude_min: bool) -> Self
pub fn exclude_min(self, exclude_min: bool) -> Self
Set whether to exclude the minimum value from the range.
Sourcepub fn exclude_max(self, exclude_max: bool) -> Self
pub fn exclude_max(self, exclude_max: bool) -> Self
Set whether to exclude the maximum value from the range.
Sourcepub fn allow_nan(self, allow: bool) -> Self
pub fn allow_nan(self, allow: bool) -> Self
Whether NaN values are allowed. Cannot be used with bounds.
Sourcepub fn allow_infinity(self, allow: bool) -> Self
pub fn allow_infinity(self, allow: bool) -> Self
Whether infinite values are allowed. Cannot be used with both bounds set.